import JSZip from 'jszip';
import { ElementType } from '../enums/element-type';
export declare type SourceSlideIdentifier = number | string;
export declare type SlideModificationCallback = (document: Document) => void;
export declare type ShapeModificationCallback = (XMLDocument: XMLDocument | Element, arg1?: Document, arg2?: Workbook) => void;
export declare type GetRelationshipsCallback = (element: Element, rels: Target[]) => void;
export declare type AutomizerParams = {
    /**
     * Prefix for all template files. You can set a path here.
     */
    templateDir?: string;
    /**
     * Specify a fallback directory if template file was not found
     * in templateDir.
     */
    templateFallbackDir?: string;
    /**
     * Prefix for the output files for `Automizer` instance.
     * You can set a path here.
     */
    outputDir?: string;
    rootTemplate?: string;
    presTemplates?: string[];
    useCreationIds?: boolean;
    /**
     * Delete all existing slides from rootTemplate
     * before automation starts.
     */
    removeExistingSlides?: boolean;
    /**
     * statusTracker will be triggered on each appended slide.
     * You can e.g. attach a custom callback to a progress bar.
     */
    statusTracker?: StatusTracker['next'];
};
export declare type StatusTracker = {
    current: number;
    max: number;
    share: number;
    info: string | undefined;
    next: (tracker: StatusTracker) => void;
    increment: () => void;
};
export declare type AutomizerSummary = {
    status: string;
    duration: number;
    file: string;
    filename: string;
    templates: number;
    slides: number;
    charts: number;
    images: number;
};
export declare type Target = {
    file: string;
    number?: number;
    rId?: string;
};
export declare type ImportElement = {
    presName: string;
    slideNumber: number;
    selector: string;
    mode: string;
    callback?: ShapeModificationCallback | ShapeModificationCallback[];
};
export declare type ImportedElement = {
    mode: string;
    name?: string;
    hasCreationId?: boolean;
    sourceArchive: JSZip;
    sourceSlideNumber: number;
    callback?: ImportElement['callback'];
    target?: AnalyzedElementType['target'];
    type?: AnalyzedElementType['type'];
    sourceElement?: AnalyzedElementType['element'];
};
export declare type AnalyzedElementType = {
    type: ElementType;
    target?: Target;
    element?: XMLDocument;
};
export declare type TargetByRelIdMapParam = {
    relRootTag: string;
    relAttribute: string;
    prefix: string;
    expression?: RegExp;
};
export declare type Workbook = {
    archive: JSZip;
    sheet: XMLDocument;
    sharedStrings: XMLDocument;
    table: XMLDocument;
};
